==> nodejs_interop-0.4.0.tar.gz: lib/src/node/os/os_constants.dart <==
part of nodejs_interop.node.os;

/// Commonly used operating system specific constants for error codes, process signals, and so on.
@JS()
abstract class OSConstants {

  /// The [`dlopen`](http://manpages.ubuntu.com/manpages/xenial/man3/dlopen.3.html) constants.
  external OSDlopenConstants get dlopen;

  /// The error constants.
  external OSErrorConstants get errno;

  /// The signal constants.
  external OSSignalConstants get signals;

  /// Value indicating whether to set `SO_REUSEADDR` when binding the handle in [`uv_udp_bind()`](http://docs.libuv.org/en/v1.x/udp.html).
  external int get UV_UDP_REUSEADDR;
}

/// Provides the [`dlopen`](http://manpages.ubuntu.com/manpages/xenial/man3/dlopen.3.html) constants.
@JS()
abstract class OSDlopenConstants {

  /// Make a self-contained library use its own symbols in preference to symbols from previously loaded libraries.
  external int get RTLD_DEEPBIND;

  /// Symbols defined by the library will be made available for symbol resolution of subsequently loaded libraries.
  external int get RTLD_GLOBAL;

  /// Perform lazy binding. Node.js sets this flag by default.
  external int get RTLD_LAZY;

  /// The converse of [RTLD_GLOBAL]. This is the default behavior if neither flag is specified.
  external int get RTLD_LOCAL;

  /// Resolve all undefined symbols in the library before `dlopen` returns.
  external int get RTLD_NOW;
}

/// Provides the error constants.
@JS()
abstract class OSErrorConstants {

  /// Indicates that the list of arguments is longer than expected.
  external int get E2BIG;

  /// Indicates that the operation did not have sufficient permissions.
  external int get EACCES;

  /// Indicates that the network address is already in use.
  external int get EADDRINUSE;

  /// Indicates that the network address is currently unavailable for use.
  external int get EADDRNOTAVAIL;

  /// Indicates that the network address family is not supported.
  external int get EAFNOSUPPORT;

  /// Indicates that there is currently no data available and to try the operation again later.
  external int get EAGAIN;

  /// Indicates that the socket already has a pending connection in progress.
  external int get EALREADY;

  /// Indicates that a file descriptor is not valid.
  external int get EBADF;

  /// Indicates an invalid data message.
  external int get EBADMSG;

  /// Indicates that a device or resource is busy.
  external int get EBUSY;

  /// Indicates that an operation was canceled.
  external int get ECANCELED;

  /// Indicates that there are no child processes.
  external int get ECHILD;

  /// Indicates that the network connection has been aborted.
  external int get ECONNABORTED;

  /// Indicates that the network connection has been refused.
  external int get ECONNREFUSED;

  /// Indicates that the network connection has been reset.
  external int get ECONNRESET;

  /// Indicates that a resource deadlock has been avoided.
  external int get EDEADLK;

  /// Indicates that a destination address is required.
  external int get EDESTADDRREQ;

  /// Indicates that an argument is out of the domain of the function.
  external int get EDOM;

  /// Indicates that the disk quota has been exceeded.
  external int get EDQUOT;

  /// Indicates that the file already exists.
  external int get EEXIST;

  /// Indicates an invalid pointer address.
  external int get EFAULT;

  /// Indicates that the file is too large.
  external int get EFBIG;

  /// Indicates that the host is unreachable.
  external int get EHOSTUNREACH;

  /// Indicates that the identifier has been removed.
  external int get EIDRM;

  /// Indicates an illegal byte sequence.
  external int get EILSEQ;

  /// Indicates that an operation is already in progress.
  external int get EINPROGRESS;

  /// Indicates that a function call was interrupted.
  external int get EINTR;

  /// Indicates that an invalid argument was provided.
  external int get EINVAL;

  /// Indicates an otherwise unspecified I/O error.
  external int get EIO;

  /// Indicates that the socket is connected.
  external int get EISCONN;

  /// Indicates that the path is a directory.
  external int get EISDIR;

  /// Indicates too many levels of symbolic links in a path.
  external int get ELOOP;

  /// Indicates that there are too many open files.
  external int get EMFILE;

  /// Indicates that there are too many hard links to a file.
  external int get EMLINK;

  /// Indicates that the provided message is too long.
  external int get EMSGSIZE;

  /// Indicates that a multihop was attempted.
  external int get EMULTIHOP;

  /// Indicates that the filename is too long.
  external int get ENAMETOOLONG;

  /// Indicates that the network is down.
  external int get ENETDOWN;

  /// Indicates that the connection has been aborted by the network.
  external int get ENETRESET;

  /// Indicates that the network is unreachable.
  external int get ENETUNREACH;

  /// Indicates too many open files in the system.
  external int get ENFILE;

  /// Indicates that no buffer space is available.
  external int get ENOBUFS;

  /// Indicates that no message is available on the stream head read queue.
  external int get ENODATA;

  /// Indicates that there is no such device.
  external int get ENODEV;

  /// Indicates that there is no such file or directory.
  external int get ENOENT;

  /// Indicates an exec format error.
  external int get ENOEXEC;

  /// Indicates that there are no locks available.
  external int get ENOLCK;

  /// Indications that a link has been severed.
  external int get ENOLINK;

  /// Indicates that there is not enough space.
  external int get ENOMEM;

  /// Indicates that there is no message of the desired type.
  external int get ENOMSG;

  /// Indicates that a given protocol is not available.
  external int get ENOPROTOOPT;

  /// Indicates that there is no space available on the device.
  external int get ENOSPC;

  /// Indicates that there are no stream resources available.
  external int get ENOSR;

  /// Indicates that a given resource is not a stream.
  external int get ENOSTR;

  /// Indicates that a function has not been implemented.
  external int get ENOSYS;

  /// Indicates that the socket is not connected.
  external int get ENOTCONN;

  /// Indicates that the path is not a directory.
  external int get ENOTDIR;

  /// Indicates that the directory is not empty.
  external int get ENOTEMPTY;

  /// Indicates that the given item is not a socket.
  external int get ENOTSOCK;

  /// Indicates that a given operation is not supported.
  external int get ENOTSUP;

  /// Indicates an inappropriate I/O control operation.
  external int get ENOTTY;

  /// Indicates no such device or address.
  external int get ENXIO;

  /// Indicates that an operation is not supported on the socket.
  external int get EOPNOTSUPP;

  /// Indicates that a value is too large to be stored in a given data type.
  external int get EOVERFLOW;

  /// Indicates that the operation is not permitted.
  external int get EPERM;

  /// Indicates a broken pipe.
  external int get EPIPE;

  /// Indicates a protocol error.
  external int get EPROTO;

  /// Indicates that a protocol is not supported.
  external int get EPROTONOSUPPORT;

  /// Indicates the wrong type of protocol for a socket.
  external int get EPROTOTYPE;

  /// Indicates that the results are too large.
  external int get ERANGE;

  /// Indicates that the file system is read only.
  external int get EROFS;

  /// Indicates an invalid seek operation.
  external int get ESPIPE;

  /// Indicates that there is no such process.
  external int get ESRCH;

  /// Indicates that the file handle is stale.
  external int get ESTALE;

  /// Indicates an expired timer.
  external int get ETIME;

  /// Indicates that the connection timed out.
  external int get ETIMEDOUT;

  /// Indicates that a text file is busy.
  external int get ETXTBSY;

  /// Indicates that the operation would block.
  external int get EWOULDBLOCK;

  /// Indicates an improper link.
  external int get EXDEV;
}

/// Provides the signal constants.
@JS()
abstract class OSSignalConstants {

  /// Sent to a process to request that it abort.
  external int get SIGABRT;

  /// Sent to a process when a system timer elapses.
  external int get SIGALRM;

  /// Sent to indicate when a user wishes to interrupt a process.
  external int get SIGBREAK;

  /// Sent to a process to notify that it has caused a bus error.
  external int get SIGBUS;

  /// Sent to a process when a child process terminates.
  external int get SIGCHLD;

  /// Sent to instruct the operating system to continue a paused process.
  external int get SIGCONT;

  /// Sent to a process to notify that it has performed an illegal arithmetic operation.
  external int get SIGFPE;

  /// Sent to indicate when a controlling terminal is closed or a parent process exits.
  external int get SIGHUP;

  /// Sent to a process to notify that it has attempted to perform an illegal, malformed, unknown or privileged instruction.
  external int get SIGILL;

  /// An alias for the [SIGPWR] property.
  external int get SIGINFO;

  /// Sent to indicate when a user wishes to interrupt a process (e.g. `Ctrl+C`).
  external int get SIGINT;

  /// Sent to a process when I/O is available.
  external int get SIGIO;

  /// An alias for the [SIGABRT] property.
  external int get SIGIOT;

  /// Sent to a process to terminate it immediately.
  external int get SIGKILL;

  /// Sent to a process when a file lock has been lost.
  external int get SIGLOST;

  /// Sent to a process when it has attempted to write to a disconnected pipe.
  external int get SIGPIPE;

  /// An alias for the [SIGIO] property.
  external int get SIGPOLL;

  /// Sent to a process when a system timer has elapsed.
  external int get SIGPROF;

  /// Sent to a process to notify of a power failure.
  external int get SIGPWR;

  /// Sent to indicate when a user wishes to terminate a process and perform a core dump.
  external int get SIGQUIT;

  /// Sent to a process to notify of a segmentation fault.
  external int get SIGSEGV;

  /// Sent to a process to request termination.
  external int get SIGTERM;

  /// Sent to a process to indicate a stack fault on a coprocessor.
  external int get SIGSTKFLT;

  /// Sent to instruct the operating system to halt a process.
  external int get SIGSTOP;

  /// Sent to a process to notify of a bad argument.
  external int get SIGSYS;

  /// Sent to a process when an exception has occurred.
  external int get SIGTRAP;

  /// Sent to a process to request it to stop.
  external int get SIGTSTP;

  /// Sent to a process when it reads from the TTY while in the background.
  external int get SIGTTIN;

  /// Sent to a process when it writes to the TTY while in the background.
  external int get SIGTTOU;

  /// An alias for the [SIGSYS] property.
  external int get SIGUNUSED;

  /// Sent to a process when a socket has urgent data to read.
  external int get SIGURG;

  /// Sent to a process to identify user-defined conditions.
  external int get SIGUSR1;

  /// Sent to a process to identify user-defined conditions.
  external int get SIGUSR2;

  /// Sent to a process when a virtual timer has elapsed.
  external int get SIGVTALRM;

  /// Sent to a process when the controlling terminal has changed its size.
  external int get SIGWINCH;

  /// Sent to a process when it has exceeded its limit on CPU usage.
  external int get SIGXCPU;

  /// Sent to a process when it grows a file larger than the maximum allowed.
  external int get SIGXFSZ;
}

==> nodejs_interop-0.7.0.tar.gz: lib/src/node/os/os_constants.dart <==
part of nodejs_interop.node;

/// Commonly used operating system specific constants for error codes, process signals, and so on.
@JS()
abstract class OSConstants {

  /// The [`dlopen`](http://manpages.ubuntu.com/manpages/xenial/man3/dlopen.3.html) constants.
  external OSDlopenConstants get dlopen;

  /// The error constants.
  external OSErrorConstants get errno;

  /// The signal constants.
  external OSSignalConstants get signals;

  /// Value indicating whether to set `SO_REUSEADDR` when binding the handle in [`uv_udp_bind()`](http://docs.libuv.org/en/v1.x/udp.html).
  external int get UV_UDP_REUSEADDR;
}

/// Provides the [`dlopen`](http://manpages.ubuntu.com/manpages/xenial/man3/dlopen.3.html) constants.
@JS()
abstract class OSDlopenConstants {

  /// Make a self-contained library use its own symbols in preference to symbols from previously loaded libraries.
  external int get RTLD_DEEPBIND;

  /// Symbols defined by the library will be made available for symbol resolution of subsequently loaded libraries.
  external int get RTLD_GLOBAL;

  /// Perform lazy binding. Node.js sets this flag by default.
  external int get RTLD_LAZY;

  /// The converse of [RTLD_GLOBAL]. This is the default behavior if neither flag is specified.
  external int get RTLD_LOCAL;

  /// Resolve all undefined symbols in the library before `dlopen` returns.
  external int get RTLD_NOW;
}

/// Provides the error constants.
@JS()
abstract class OSErrorConstants {

  /// Indicates that the list of arguments is longer than expected.
  external int get E2BIG;

  /// Indicates that the operation did not have sufficient permissions.
  external int get EACCES;

  /// Indicates that the network address is already in use.
  external int get EADDRINUSE;

  /// Indicates that the network address is currently unavailable for use.
  external int get EADDRNOTAVAIL;

  /// Indicates that the network address family is not supported.
  external int get EAFNOSUPPORT;

  /// Indicates that there is currently no data available and to try the operation again later.
  external int get EAGAIN;

  /// Indicates that the socket already has a pending connection in progress.
  external int get EALREADY;

  /// Indicates that a file descriptor is not valid.
  external int get EBADF;

  /// Indicates an invalid data message.
  external int get EBADMSG;

  /// Indicates that a device or resource is busy.
  external int get EBUSY;

  /// Indicates that an operation was canceled.
  external int get ECANCELED;

  /// Indicates that there are no child processes.
  external int get ECHILD;

  /// Indicates that the network connection has been aborted.
  external int get ECONNABORTED;

  /// Indicates that the network connection has been refused.
  external int get ECONNREFUSED;

  /// Indicates that the network connection has been reset.
  external int get ECONNRESET;

  /// Indicates that a resource deadlock has been avoided.
  external int get EDEADLK;

  /// Indicates that a destination address is required.
  external int get EDESTADDRREQ;

  /// Indicates that an argument is out of the domain of the function.
  external int get EDOM;

  /// Indicates that the disk quota has been exceeded.
  external int get EDQUOT;

  /// Indicates that the file already exists.
  external int get EEXIST;

  /// Indicates an invalid pointer address.
  external int get EFAULT;

  /// Indicates that the file is too large.
  external int get EFBIG;

  /// Indicates that the host is unreachable.
  external int get EHOSTUNREACH;

  /// Indicates that the identifier has been removed.
  external int get EIDRM;

  /// Indicates an illegal byte sequence.
  external int get EILSEQ;

  /// Indicates that an operation is already in progress.
  external int get EINPROGRESS;

  /// Indicates that a function call was interrupted.
  external int get EINTR;

  /// Indicates that an invalid argument was provided.
  external int get EINVAL;

  /// Indicates an otherwise unspecified I/O error.
  external int get EIO;

  /// Indicates that the socket is connected.
  external int get EISCONN;

  /// Indicates that the path is a directory.
  external int get EISDIR;

  /// Indicates too many levels of symbolic links in a path.
  external int get ELOOP;

  /// Indicates that there are too many open files.
  external int get EMFILE;

  /// Indicates that there are too many hard links to a file.
  external int get EMLINK;

  /// Indicates that the provided message is too long.
  external int get EMSGSIZE;

  /// Indicates that a multihop was attempted.
  external int get EMULTIHOP;

  /// Indicates that the filename is too long.
  external int get ENAMETOOLONG;

  /// Indicates that the network is down.
  external int get ENETDOWN;

  /// Indicates that the connection has been aborted by the network.
  external int get ENETRESET;

  /// Indicates that the network is unreachable.
  external int get ENETUNREACH;

  /// Indicates too many open files in the system.
  external int get ENFILE;

  /// Indicates that no buffer space is available.
  external int get ENOBUFS;

  /// Indicates that no message is available on the stream head read queue.
  external int get ENODATA;

  /// Indicates that there is no such device.
  external int get ENODEV;

  /// Indicates that there is no such file or directory.
  external int get ENOENT;

  /// Indicates an exec format error.
  external int get ENOEXEC;

  /// Indicates that there are no locks available.
  external int get ENOLCK;

  /// Indications that a link has been severed.
  external int get ENOLINK;

  /// Indicates that there is not enough space.
  external int get ENOMEM;

  /// Indicates that there is no message of the desired type.
  external int get ENOMSG;

  /// Indicates that a given protocol is not available.
  external int get ENOPROTOOPT;

  /// Indicates that there is no space available on the device.
  external int get ENOSPC;

  /// Indicates that there are no stream resources available.
  external int get ENOSR;

  /// Indicates that a given resource is not a stream.
  external int get ENOSTR;

  /// Indicates that a function has not been implemented.
  external int get ENOSYS;

  /// Indicates that the socket is not connected.
  external int get ENOTCONN;

  /// Indicates that the path is not a directory.
  external int get ENOTDIR;

  /// Indicates that the directory is not empty.
  external int get ENOTEMPTY;

  /// Indicates that the given item is not a socket.
  external int get ENOTSOCK;

  /// Indicates that a given operation is not supported.
  external int get ENOTSUP;

  /// Indicates an inappropriate I/O control operation.
  external int get ENOTTY;

  /// Indicates no such device or address.
  external int get ENXIO;

  /// Indicates that an operation is not supported on the socket.
  external int get EOPNOTSUPP;

  /// Indicates that a value is too large to be stored in a given data type.
  external int get EOVERFLOW;

  /// Indicates that the operation is not permitted.
  external int get EPERM;

  /// Indicates a broken pipe.
  external int get EPIPE;

  /// Indicates a protocol error.
  external int get EPROTO;

  /// Indicates that a protocol is not supported.
  external int get EPROTONOSUPPORT;

  /// Indicates the wrong type of protocol for a socket.
  external int get EPROTOTYPE;

  /// Indicates that the results are too large.
  external int get ERANGE;

  /// Indicates that the file system is read only.
  external int get EROFS;

  /// Indicates an invalid seek operation.
  external int get ESPIPE;

  /// Indicates that there is no such process.
  external int get ESRCH;

  /// Indicates that the file handle is stale.
  external int get ESTALE;

  /// Indicates an expired timer.
  external int get ETIME;

  /// Indicates that the connection timed out.
  external int get ETIMEDOUT;

  /// Indicates that a text file is busy.
  external int get ETXTBSY;

  /// Indicates that the operation would block.
  external int get EWOULDBLOCK;

  /// Indicates an improper link.
  external int get EXDEV;
}

/// Provides the signal constants.
@JS()
abstract class OSSignalConstants {

  /// Sent to a process to request that it abort.
  external int get SIGABRT;

  /// Sent to a process when a system timer elapses.
  external int get SIGALRM;

  /// Sent to indicate when a user wishes to interrupt a process.
  external int get SIGBREAK;

  /// Sent to a process to notify that it has caused a bus error.
  external int get SIGBUS;

  /// Sent to a process when a child process terminates.
  external int get SIGCHLD;

  /// Sent to instruct the operating system to continue a paused process.
  external int get SIGCONT;

  /// Sent to a process to notify that it has performed an illegal arithmetic operation.
  external int get SIGFPE;

  /// Sent to indicate when a controlling terminal is closed or a parent process exits.
  external int get SIGHUP;

  /// Sent to a process to notify that it has attempted to perform an illegal, malformed, unknown or privileged instruction.
  external int get SIGILL;

  /// An alias for the [SIGPWR] property.
  external int get SIGINFO;

  /// Sent to indicate when a user wishes to interrupt a process (i.e. `Ctrl+C`).
  external int get SIGINT;

  /// Sent to a process when I/O is available.
  external int get SIGIO;

  /// An alias for the [SIGABRT] property.
  external int get SIGIOT;

  /// Sent to a process to terminate it immediately.
  external int get SIGKILL;

  /// Sent to a process when a file lock has been lost.
  external int get SIGLOST;

  /// Sent to a process when it has attempted to write to a disconnected pipe.
  external int get SIGPIPE;

  /// An alias for the [SIGIO] property.
  external int get SIGPOLL;

  /// Sent to a process when a system timer has elapsed.
  external int get SIGPROF;

  /// Sent to a process to notify of a power failure.
  external int get SIGPWR;

  /// Sent to indicate when a user wishes to terminate a process and perform a core dump.
  external int get SIGQUIT;

  /// Sent to a process to notify of a segmentation fault.
  external int get SIGSEGV;

  /// Sent to a process to request termination.
  external int get SIGTERM;

  /// Sent to a process to indicate a stack fault on a coprocessor.
  external int get SIGSTKFLT;

  /// Sent to instruct the operating system to halt a process.
  external int get SIGSTOP;

  /// Sent to a process to notify of a bad argument.
  external int get SIGSYS;

  /// Sent to a process when an exception has occurred.
  external int get SIGTRAP;

  /// Sent to a process to request it to stop.
  external int get SIGTSTP;

  /// Sent to a process when it reads from the TTY while in the background.
  external int get SIGTTIN;

  /// Sent to a process when it writes to the TTY while in the background.
  external int get SIGTTOU;

  /// An alias for the [SIGSYS] property.
  external int get SIGUNUSED;

  /// Sent to a process when a socket has urgent data to read.
  external int get SIGURG;

  /// Sent to a process to identify user-defined conditions.
  external int get SIGUSR1;

  /// Sent to a process to identify user-defined conditions.
  external int get SIGUSR2;

  /// Sent to a process when a virtual timer has elapsed.
  external int get SIGVTALRM;

  /// Sent to a process when the controlling terminal has changed its size.
  external int get SIGWINCH;

  /// Sent to a process when it has exceeded its limit on CPU usage.
  external int get SIGXCPU;

  /// Sent to a process when it grows a file larger than the maximum allowed.
  external int get SIGXFSZ;
}
